Class: Aws::CodePipeline::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodePipeline::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codepipeline/client.rb,
sig/client.rbs
Overview
An API client for CodePipeline. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodePipeline::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AcknowledgeJobResponseSuccess, _AcknowledgeThirdPartyJobResponseSuccess, _CreateCustomActionTypeResponseSuccess, _CreatePipelineResponseSuccess, _DeleteWebhookResponseSuccess, _DeregisterWebhookWithThirdPartyResponseSuccess, _GetActionTypeResponseSuccess, _GetJobDetailsResponseSuccess, _GetPipelineExecutionResponseSuccess, _GetPipelineResponseSuccess, _GetPipelineStateResponseSuccess, _GetThirdPartyJobDetailsResponseSuccess, _ListActionExecutionsResponseSuccess, _ListActionTypesResponseSuccess, _ListDeployActionExecutionTargetsResponseSuccess, _ListPipelineExecutionsResponseSuccess, _ListPipelinesResponseSuccess, _ListRuleExecutionsResponseSuccess, _ListRuleTypesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWebhooksResponseSuccess, _PollForJobsResponseSuccess, _PollForThirdPartyJobsResponseSuccess, _PutActionRevisionResponseSuccess, _PutApprovalResultResponseSuccess, _PutWebhookResponseSuccess, _RegisterWebhookWithThirdPartyResponseSuccess, _RetryStageExecutionResponseSuccess, _RollbackStageResponseSuccess, _StartPipelineExecutionResponseSuccess, _StopPipelineExecutionResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdatePipelineResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#acknowledge_job(params = {}) ⇒ Types::AcknowledgeJobOutput
Returns information about a specified job and whether that job has been received by the job worker.
-
#acknowledge_third_party_job(params = {}) ⇒ Types::AcknowledgeThirdPartyJobOutput
Confirms a job worker has received the specified job.
-
#create_custom_action_type(params = {}) ⇒ Types::CreateCustomActionTypeOutput
Creates a new custom action that can be used in all pipelines associated with the Amazon Web Services account.
-
#create_pipeline(params = {}) ⇒ Types::CreatePipelineOutput
Creates a pipeline.
-
#delete_custom_action_type(params = {}) ⇒ Struct
Marks a custom action as deleted.
-
#delete_pipeline(params = {}) ⇒ Struct
Deletes the specified pipeline.
-
#delete_webhook(params = {}) ⇒ Struct
Deletes a previously created webhook by name.
-
#deregister_webhook_with_third_party(params = {}) ⇒ Struct
Removes the connection between the webhook that was created by CodePipeline and the external tool with events to be detected.
-
#disable_stage_transition(params = {}) ⇒ Struct
Prevents artifacts in a pipeline from transitioning to the next stage in the pipeline.
-
#enable_stage_transition(params = {}) ⇒ Struct
Enables artifacts in a pipeline to transition to a stage in a pipeline.
-
#get_action_type(params = {}) ⇒ Types::GetActionTypeOutput
Returns information about an action type created for an external provider, where the action is to be used by customers of the external provider.
-
#get_job_details(params = {}) ⇒ Types::GetJobDetailsOutput
Returns information about a job.
-
#get_pipeline(params = {}) ⇒ Types::GetPipelineOutput
Returns the metadata, structure, stages, and actions of a pipeline.
-
#get_pipeline_execution(params = {}) ⇒ Types::GetPipelineExecutionOutput
Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.
-
#get_pipeline_state(params = {}) ⇒ Types::GetPipelineStateOutput
Returns information about the state of a pipeline, including the stages and actions.
-
#get_third_party_job_details(params = {}) ⇒ Types::GetThirdPartyJobDetailsOutput
Requests the details of a job for a third party action.
-
#list_action_executions(params = {}) ⇒ Types::ListActionExecutionsOutput
Lists the action executions that have occurred in a pipeline.
-
#list_action_types(params = {}) ⇒ Types::ListActionTypesOutput
Gets a summary of all CodePipeline action types associated with your account.
-
#list_deploy_action_execution_targets(params = {}) ⇒ Types::ListDeployActionExecutionTargetsOutput
Lists the targets for the deploy action.
-
#list_pipeline_executions(params = {}) ⇒ Types::ListPipelineExecutionsOutput
Gets a summary of the most recent executions for a pipeline.
-
#list_pipelines(params = {}) ⇒ Types::ListPipelinesOutput
Gets a summary of all of the pipelines associated with your account.
-
#list_rule_executions(params = {}) ⇒ Types::ListRuleExecutionsOutput
Lists the rule executions that have occurred in a pipeline configured for conditions with rules.
-
#list_rule_types(params = {}) ⇒ Types::ListRuleTypesOutput
Lists the rules for the condition.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Gets the set of key-value pairs (metadata) that are used to manage the resource.
-
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
Gets a listing of all the webhooks in this Amazon Web Services Region for this account.
-
#override_stage_condition(params = {}) ⇒ Struct
Used to override a stage condition.
-
#poll_for_jobs(params = {}) ⇒ Types::PollForJobsOutput
Returns information about any jobs for CodePipeline to act on.
-
#poll_for_third_party_jobs(params = {}) ⇒ Types::PollForThirdPartyJobsOutput
Determines whether there are any third party jobs for a job worker to act on.
-
#put_action_revision(params = {}) ⇒ Types::PutActionRevisionOutput
Provides information to CodePipeline about new revisions to a source.
-
#put_approval_result(params = {}) ⇒ Types::PutApprovalResultOutput
Provides the response to a manual approval request to CodePipeline.
-
#put_job_failure_result(params = {}) ⇒ Struct
Represents the failure of a job as returned to the pipeline by a job worker.
-
#put_job_success_result(params = {}) ⇒ Struct
Represents the success of a job as returned to the pipeline by a job worker.
-
#put_third_party_job_failure_result(params = {}) ⇒ Struct
Represents the failure of a third party job as returned to the pipeline by a job worker.
-
#put_third_party_job_success_result(params = {}) ⇒ Struct
Represents the success of a third party job as returned to the pipeline by a job worker.
-
#put_webhook(params = {}) ⇒ Types::PutWebhookOutput
Defines a webhook and returns a unique webhook URL generated by CodePipeline.
-
#register_webhook_with_third_party(params = {}) ⇒ Struct
Configures a connection between the webhook that was created and the external tool with events to be detected.
-
#retry_stage_execution(params = {}) ⇒ Types::RetryStageExecutionOutput
You can retry a stage that has failed without having to run a pipeline again from the beginning.
-
#rollback_stage(params = {}) ⇒ Types::RollbackStageOutput
Rolls back a stage execution.
-
#start_pipeline_execution(params = {}) ⇒ Types::StartPipelineExecutionOutput
Starts the specified pipeline.
-
#stop_pipeline_execution(params = {}) ⇒ Types::StopPipelineExecutionOutput
Stops the specified pipeline execution.
-
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
-
#update_action_type(params = {}) ⇒ Struct
Updates an action type that was created with any supported integration model, where the action type is to be used by customers of the action type provider.
-
#update_pipeline(params = {}) ⇒ Types::UpdatePipelineOutput
Updates a specified pipeline with edits or changes to its structure.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-codepipeline/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3788 3789 3790 |
# File 'lib/aws-sdk-codepipeline/client.rb', line 3788 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3791 3792 3793 |
# File 'lib/aws-sdk-codepipeline/client.rb', line 3791 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#acknowledge_job(params = {}) ⇒ Types::AcknowledgeJobOutput
Returns information about a specified job and whether that job has been received by the job worker. Used for custom actions only.
87 |
# File 'sig/client.rbs', line 87
def acknowledge_job: (
|
#acknowledge_third_party_job(params = {}) ⇒ Types::AcknowledgeThirdPartyJobOutput
Confirms a job worker has received the specified job. Used for partner actions only.
98 |
# File 'sig/client.rbs', line 98
def acknowledge_third_party_job: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 3772 3773 3774 3775 3776 3777 |
# File 'lib/aws-sdk-codepipeline/client.rb', line 3761 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodePipeline') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codepipeline' context[:gem_version] = '1.118.0' Seahorse::Client::Request.new(handlers, context) end |
#create_custom_action_type(params = {}) ⇒ Types::CreateCustomActionTypeOutput
Creates a new custom action that can be used in all pipelines associated with the Amazon Web Services account. Only used for custom actions.
111 |
# File 'sig/client.rbs', line 111
def create_custom_action_type: (
|
#create_pipeline(params = {}) ⇒ Types::CreatePipelineOutput
Creates a pipeline.
artifactStore or
artifactStores in your pipeline, but you cannot use both. If you
create a cross-region action in your pipeline, you must use
artifactStores.
155 |
# File 'sig/client.rbs', line 155
def create_pipeline: (
|
#delete_custom_action_type(params = {}) ⇒ Struct
Marks a custom action as deleted. PollForJobs for the custom action
fails after the action is marked for deletion. Used for custom actions
only.
To re-create a custom action after it has been deleted you must use a string in the version field that has never been used before. This string can be an incremented version number, for example. To restore a deleted custom action, use a JSON file that is identical to the deleted action, including the original string in the version field.
167 |
# File 'sig/client.rbs', line 167
def delete_custom_action_type: (
|
#delete_pipeline(params = {}) ⇒ Struct
Deletes the specified pipeline.
175 |
# File 'sig/client.rbs', line 175
def delete_pipeline: (
|
#delete_webhook(params = {}) ⇒ Struct
Deletes a previously created webhook by name. Deleting the webhook stops CodePipeline from starting a pipeline every time an external event occurs. The API returns successfully when trying to delete a webhook that is already deleted. If a deleted webhook is re-created by calling PutWebhook with the same name, it will have a different URL.
184 |
# File 'sig/client.rbs', line 184
def delete_webhook: (
|
#deregister_webhook_with_third_party(params = {}) ⇒ Struct
Removes the connection between the webhook that was created by CodePipeline and the external tool with events to be detected. Currently supported only for webhooks that target an action type of GitHub.
193 |
# File 'sig/client.rbs', line 193
def deregister_webhook_with_third_party: (
|
#disable_stage_transition(params = {}) ⇒ Struct
Prevents artifacts in a pipeline from transitioning to the next stage in the pipeline.
199 |
# File 'sig/client.rbs', line 199
def disable_stage_transition: (
|
#enable_stage_transition(params = {}) ⇒ Struct
Enables artifacts in a pipeline to transition to a stage in a pipeline.
208 |
# File 'sig/client.rbs', line 208
def enable_stage_transition: (
|
#get_action_type(params = {}) ⇒ Types::GetActionTypeOutput
Returns information about an action type created for an external provider, where the action is to be used by customers of the external provider. The action can be created with any supported integration model.
220 |
# File 'sig/client.rbs', line 220
def get_action_type: (
|
#get_job_details(params = {}) ⇒ Types::GetJobDetailsOutput
Returns information about a job. Used for custom actions only.
When this API is called, CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts. This API also returns any secret values defined for the action.
233 |
# File 'sig/client.rbs', line 233
def get_job_details: (
|
#get_pipeline(params = {}) ⇒ Types::GetPipelineOutput
Returns the metadata, structure, stages, and actions of a pipeline. Can be used to return the entire structure of a pipeline in JSON format, which can then be modified and used to update the pipeline structure with UpdatePipeline.
244 |
# File 'sig/client.rbs', line 244
def get_pipeline: (
|
#get_pipeline_execution(params = {}) ⇒ Types::GetPipelineExecutionOutput
Returns information about an execution of a pipeline, including details about artifacts, the pipeline execution ID, and the name, version, and status of the pipeline.
255 |
# File 'sig/client.rbs', line 255
def get_pipeline_execution: (
|
#get_pipeline_state(params = {}) ⇒ Types::GetPipelineStateOutput
Returns information about the state of a pipeline, including the stages and actions.
revisionId and revisionUrl fields indicate
the source revision information, such as the commit ID, for the
current state.
270 |
# File 'sig/client.rbs', line 270
def get_pipeline_state: (
|
#get_third_party_job_details(params = {}) ⇒ Types::GetThirdPartyJobDetailsOutput
Requests the details of a job for a third party action. Used for partner actions only.
When this API is called, CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts. This API also returns any secret values defined for the action.
280 |
# File 'sig/client.rbs', line 280
def get_third_party_job_details: (
|
#list_action_executions(params = {}) ⇒ Types::ListActionExecutionsOutput
Lists the action executions that have occurred in a pipeline.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
292 |
# File 'sig/client.rbs', line 292
def list_action_executions: (
|
#list_action_types(params = {}) ⇒ Types::ListActionTypesOutput
Gets a summary of all CodePipeline action types associated with your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
312 |
# File 'sig/client.rbs', line 312
def list_action_types: (
|
#list_deploy_action_execution_targets(params = {}) ⇒ Types::ListDeployActionExecutionTargetsOutput
Lists the targets for the deploy action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
325 |
# File 'sig/client.rbs', line 325
def list_deploy_action_execution_targets: (
|
#list_pipeline_executions(params = {}) ⇒ Types::ListPipelineExecutionsOutput
Gets a summary of the most recent executions for a pipeline.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
345 |
# File 'sig/client.rbs', line 345
def list_pipeline_executions: (
|
#list_pipelines(params = {}) ⇒ Types::ListPipelinesOutput
Gets a summary of all of the pipelines associated with your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
363 |
# File 'sig/client.rbs', line 363
def list_pipelines: (
|
#list_rule_executions(params = {}) ⇒ Types::ListRuleExecutionsOutput
Lists the rule executions that have occurred in a pipeline configured for conditions with rules.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
375 |
# File 'sig/client.rbs', line 375
def list_rule_executions: (
|
#list_rule_types(params = {}) ⇒ Types::ListRuleTypesOutput
Lists the rules for the condition. For more information about conditions, see Stage conditions and How do stage conditions work?.For more information about rules, see the CodePipeline rule reference.
394 |
# File 'sig/client.rbs', line 394
def list_rule_types: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Gets the set of key-value pairs (metadata) that are used to manage the resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
406 |
# File 'sig/client.rbs', line 406
def list_tags_for_resource: (
|
#list_webhooks(params = {}) ⇒ Types::ListWebhooksOutput
Gets a listing of all the webhooks in this Amazon Web Services Region for this account. The output lists all webhooks and includes the webhook URL and ARN and the configuration for each webhook.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
419 |
# File 'sig/client.rbs', line 419
def list_webhooks: (
|
#override_stage_condition(params = {}) ⇒ Struct
Used to override a stage condition. For more information about conditions, see Stage conditions and How do stage conditions work?.
426 |
# File 'sig/client.rbs', line 426
def override_stage_condition: (
|
#poll_for_jobs(params = {}) ⇒ Types::PollForJobsOutput
Returns information about any jobs for CodePipeline to act on.
PollForJobs is valid only for action types with "Custom" in the
owner field. If the action type contains AWS or ThirdParty in the
owner field, the PollForJobs action returns an error.
When this API is called, CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts. This API also returns any secret values defined for the action.
439 |
# File 'sig/client.rbs', line 439
def poll_for_jobs: (
|
#poll_for_third_party_jobs(params = {}) ⇒ Types::PollForThirdPartyJobsOutput
Determines whether there are any third party jobs for a job worker to act on. Used for partner actions only.
When this API is called, CodePipeline returns temporary credentials for the S3 bucket used to store artifacts for the pipeline, if the action requires access to that S3 bucket for input or output artifacts.
456 |
# File 'sig/client.rbs', line 456
def poll_for_third_party_jobs: (
|
#put_action_revision(params = {}) ⇒ Types::PutActionRevisionOutput
Provides information to CodePipeline about new revisions to a source.
473 |
# File 'sig/client.rbs', line 473
def put_action_revision: (
|
#put_approval_result(params = {}) ⇒ Types::PutApprovalResultOutput
Provides the response to a manual approval request to CodePipeline. Valid responses include Approved and Rejected.
490 |
# File 'sig/client.rbs', line 490
def put_approval_result: (
|
#put_job_failure_result(params = {}) ⇒ Struct
Represents the failure of a job as returned to the pipeline by a job worker. Used for custom actions only.
503 |
# File 'sig/client.rbs', line 503
def put_job_failure_result: (
|
#put_job_success_result(params = {}) ⇒ Struct
Represents the success of a job as returned to the pipeline by a job worker. Used for custom actions only.
514 |
# File 'sig/client.rbs', line 514
def put_job_success_result: (
|
#put_third_party_job_failure_result(params = {}) ⇒ Struct
Represents the failure of a third party job as returned to the pipeline by a job worker. Used for partner actions only.
533 |
# File 'sig/client.rbs', line 533
def put_third_party_job_failure_result: (
|
#put_third_party_job_success_result(params = {}) ⇒ Struct
Represents the success of a third party job as returned to the pipeline by a job worker. Used for partner actions only.
545 |
# File 'sig/client.rbs', line 545
def put_third_party_job_success_result: (
|
#put_webhook(params = {}) ⇒ Types::PutWebhookOutput
Defines a webhook and returns a unique webhook URL generated by CodePipeline. This URL can be supplied to third party source hosting providers to call every time there's a code change. When CodePipeline receives a POST request on this URL, the pipeline defined in the webhook is started as long as the POST request satisfied the authentication and filtering requirements supplied when defining the webhook. RegisterWebhookWithThirdParty and DeregisterWebhookWithThirdParty APIs can be used to automatically configure supported third parties to call the generated webhook URL.
When creating CodePipeline webhooks, do not use your own credentials or reuse the same secret token across multiple webhooks. For optimal security, generate a unique secret token for each webhook you create. The secret token is an arbitrary string that you provide, which GitHub uses to compute and sign the webhook payloads sent to CodePipeline, for protecting the integrity and authenticity of the webhook payloads. Using your own credentials or reusing the same token across multiple webhooks can lead to security vulnerabilities.
568 |
# File 'sig/client.rbs', line 568
def put_webhook: (
|
#register_webhook_with_third_party(params = {}) ⇒ Struct
Configures a connection between the webhook that was created and the external tool with events to be detected.
598 |
# File 'sig/client.rbs', line 598
def register_webhook_with_third_party: (
|
#retry_stage_execution(params = {}) ⇒ Types::RetryStageExecutionOutput
You can retry a stage that has failed without having to run a pipeline again from the beginning. You do this by either retrying the failed actions in a stage or by retrying all actions in the stage starting from the first action in the stage. When you retry the failed actions in a stage, all actions that are still in progress continue working, and failed actions are triggered again. When you retry a failed stage from the first action in the stage, the stage cannot have any actions in progress. Before a stage can be retried, it must either have all actions failed or some actions failed and some succeeded.
608 |
# File 'sig/client.rbs', line 608
def retry_stage_execution: (
|
#rollback_stage(params = {}) ⇒ Types::RollbackStageOutput
Rolls back a stage execution.
621 |
# File 'sig/client.rbs', line 621
def rollback_stage: (
|
#start_pipeline_execution(params = {}) ⇒ Types::StartPipelineExecutionOutput
Starts the specified pipeline. Specifically, it begins processing the latest commit to the source location specified as part of the pipeline.
633 |
# File 'sig/client.rbs', line 633
def start_pipeline_execution: (
|
#stop_pipeline_execution(params = {}) ⇒ Types::StopPipelineExecutionOutput
Stops the specified pipeline execution. You choose to either stop the
pipeline execution by completing in-progress actions without starting
subsequent actions, or by abandoning in-progress actions. While
completing or abandoning in-progress actions, the pipeline execution
is in a Stopping state. After all in-progress actions are completed
or abandoned, the pipeline execution is in a Stopped state.
657 |
# File 'sig/client.rbs', line 657
def stop_pipeline_execution: (
|
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource. Tags are metadata that can be used to manage a resource.
669 |
# File 'sig/client.rbs', line 669
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
684 |
# File 'sig/client.rbs', line 684
def untag_resource: (
|
#update_action_type(params = {}) ⇒ Struct
Updates an action type that was created with any supported integration
model, where the action type is to be used by customers of the action
type provider. Use a JSON file with the action definition and
UpdateActionType to provide the full structure.
691 |
# File 'sig/client.rbs', line 691
def update_action_type: (
|
#update_pipeline(params = {}) ⇒ Types::UpdatePipelineOutput
Updates a specified pipeline with edits or changes to its structure.
Use a JSON file with the pipeline structure and UpdatePipeline to
provide the full structure of the pipeline. Updating the pipeline
increases the version number of the pipeline by 1.
750 |
# File 'sig/client.rbs', line 750
def update_pipeline: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3781 3782 3783 |
# File 'lib/aws-sdk-codepipeline/client.rb', line 3781 def waiter_names [] end |