Class: Aws::CodePipeline::Types::EnableStageTransitionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodePipeline::Types::EnableStageTransitionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codepipeline/types.rb
Overview
Represents the input of an EnableStageTransition action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pipeline_name ⇒ String
The name of the pipeline in which you want to enable the flow of artifacts from one stage to another.
-
#stage_name ⇒ String
The name of the stage where you want to enable the transition of artifacts, either into the stage (inbound) or from that stage to the next stage (outbound).
-
#transition_type ⇒ String
Specifies whether artifacts are allowed to enter the stage and be processed by the actions in that stage (inbound) or whether already processed artifacts are allowed to transition to the next stage (outbound).
Instance Attribute Details
#pipeline_name ⇒ String
The name of the pipeline in which you want to enable the flow of artifacts from one stage to another.
1877 1878 1879 1880 1881 1882 1883 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 1877 class EnableStageTransitionInput < Struct.new( :pipeline_name, :stage_name, :transition_type) SENSITIVE = [] include Aws::Structure end |
#stage_name ⇒ String
The name of the stage where you want to enable the transition of artifacts, either into the stage (inbound) or from that stage to the next stage (outbound).
1877 1878 1879 1880 1881 1882 1883 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 1877 class EnableStageTransitionInput < Struct.new( :pipeline_name, :stage_name, :transition_type) SENSITIVE = [] include Aws::Structure end |
#transition_type ⇒ String
Specifies whether artifacts are allowed to enter the stage and be processed by the actions in that stage (inbound) or whether already processed artifacts are allowed to transition to the next stage (outbound).
1877 1878 1879 1880 1881 1882 1883 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 1877 class EnableStageTransitionInput < Struct.new( :pipeline_name, :stage_name, :transition_type) SENSITIVE = [] include Aws::Structure end |