Class: Aws::CodePipeline::Types::GetPipelineStateOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codepipeline/types.rb

Overview

Represents the output of a GetPipelineState action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#createdTime

The date and time the pipeline was created, in timestamp format.



2311
2312
2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-codepipeline/types.rb', line 2311

class GetPipelineStateOutput < Struct.new(
  :pipeline_name,
  :pipeline_version,
  :stage_states,
  :created,
  :updated)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline for which you want to get the state.



2311
2312
2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-codepipeline/types.rb', line 2311

class GetPipelineStateOutput < Struct.new(
  :pipeline_name,
  :pipeline_version,
  :stage_states,
  :created,
  :updated)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_versionInteger

The version number of the pipeline.

A newly created pipeline is always assigned a version number of 1.



2311
2312
2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-codepipeline/types.rb', line 2311

class GetPipelineStateOutput < Struct.new(
  :pipeline_name,
  :pipeline_version,
  :stage_states,
  :created,
  :updated)
  SENSITIVE = []
  include Aws::Structure
end

#stage_statesArray<Types::StageState>

A list of the pipeline stage output information, including stage name, state, most recent run details, whether the stage is disabled, and other data.



2311
2312
2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-codepipeline/types.rb', line 2311

class GetPipelineStateOutput < Struct.new(
  :pipeline_name,
  :pipeline_version,
  :stage_states,
  :created,
  :updated)
  SENSITIVE = []
  include Aws::Structure
end

#updatedTime

The date and time the pipeline was last updated, in timestamp format.



2311
2312
2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-codepipeline/types.rb', line 2311

class GetPipelineStateOutput < Struct.new(
  :pipeline_name,
  :pipeline_version,
  :stage_states,
  :created,
  :updated)
  SENSITIVE = []
  include Aws::Structure
end