Class: Aws::CodePipeline::Types::ListActionTypesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codepipeline/types.rb

Overview

Represents the input of a ‘ListActionTypes` action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_owner_filterString

Filters the list of action types to those created by a specified entity.



2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-codepipeline/types.rb', line 2926

class ListActionTypesInput < Struct.new(
  :action_owner_filter,
  :next_token,
  :region_filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous list action types call, which can be used to return the next set of action types in the list.



2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-codepipeline/types.rb', line 2926

class ListActionTypesInput < Struct.new(
  :action_owner_filter,
  :next_token,
  :region_filter)
  SENSITIVE = []
  include Aws::Structure
end

#region_filterString

The Region to filter on for the list of action types.



2926
2927
2928
2929
2930
2931
2932
# File 'lib/aws-sdk-codepipeline/types.rb', line 2926

class ListActionTypesInput < Struct.new(
  :action_owner_filter,
  :next_token,
  :region_filter)
  SENSITIVE = []
  include Aws::Structure
end