Class: Aws::CodePipeline::Types::PipelineExecutionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codepipeline/types.rb

Overview

Summary information about a pipeline execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_modeString

The method that the pipeline will use to handle multiple executions. The default mode is SUPERSEDED.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#execution_typeString

Type of the pipeline execution.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_timeTime

The date and time of the last change to the pipeline execution, in timestamp format.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_idString

The ID of the pipeline execution.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_metadataTypes::PipelineRollbackMetadata

The metadata for the stage execution to be rolled back.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#source_revisionsArray<Types::SourceRevision>

A list of the source artifact revisions that initiated a pipeline execution.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The date and time when the pipeline execution began, in timestamp format.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the pipeline execution.

  • InProgress: The pipeline execution is currently running.

  • Stopped: The pipeline execution was manually stopped. For more information, see Stopped Executions.

  • Stopping: The pipeline execution received a request to be manually stopped. Depending on the selected stop mode, the execution is either completing or abandoning in-progress actions. For more information, see Stopped Executions.

  • Succeeded: The pipeline execution was completed successfully.

  • Superseded: While this pipeline execution was waiting for the next stage to be completed, a newer pipeline execution advanced and continued through the pipeline instead. For more information, see Superseded Executions.

  • Failed: The pipeline execution was not completed successfully.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#status_summaryString

Status summary for the pipeline.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#stop_triggerTypes::StopExecutionTrigger

The interaction that stopped a pipeline execution.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end

#triggerTypes::ExecutionTrigger

The interaction or event that started a pipeline execution, such as automated change detection or a StartPipelineExecution API call.



3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
3796
3797
3798
3799
# File 'lib/aws-sdk-codepipeline/types.rb', line 3785

class PipelineExecutionSummary < Struct.new(
  :pipeline_execution_id,
  :status,
  :status_summary,
  :start_time,
  :last_update_time,
  :source_revisions,
  :trigger,
  :stop_trigger,
  :execution_mode,
  :execution_type,
  :rollback_metadata)
  SENSITIVE = []
  include Aws::Structure
end