Class: Aws::CodePipeline::Types::RetryStageExecutionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codepipeline/types.rb

Overview

Represents the input of a RetryStageExecution action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pipeline_execution_idString

The ID of the pipeline execution in the failed stage to be retried. Use the GetPipelineState action to retrieve the current pipelineExecutionId of the failed stage

Returns:



4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473

class RetryStageExecutionInput < Struct.new(
  :pipeline_name,
  :stage_name,
  :pipeline_execution_id,
  :retry_mode)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline that contains the failed stage.

Returns:



4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473

class RetryStageExecutionInput < Struct.new(
  :pipeline_name,
  :stage_name,
  :pipeline_execution_id,
  :retry_mode)
  SENSITIVE = []
  include Aws::Structure
end

#retry_modeString

The scope of the retry attempt.

Returns:



4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473

class RetryStageExecutionInput < Struct.new(
  :pipeline_name,
  :stage_name,
  :pipeline_execution_id,
  :retry_mode)
  SENSITIVE = []
  include Aws::Structure
end

#stage_nameString

The name of the failed stage to be retried.

Returns:



4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473

class RetryStageExecutionInput < Struct.new(
  :pipeline_name,
  :stage_name,
  :pipeline_execution_id,
  :retry_mode)
  SENSITIVE = []
  include Aws::Structure
end