Class: Aws::CodePipeline::Types::StopPipelineExecutionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codepipeline/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#abandonBoolean

Use this option to stop the pipeline execution by abandoning, rather than finishing, in-progress actions.

<note markdown=“1”> This option can lead to failed or out-of-sequence tasks.

</note>


5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-codepipeline/types.rb', line 5536

class StopPipelineExecutionInput < Struct.new(
  :pipeline_name,
  :pipeline_execution_id,
  :abandon,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_idString

The ID of the pipeline execution to be stopped in the current stage. Use the GetPipelineState action to retrieve the current pipelineExecutionId.



5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-codepipeline/types.rb', line 5536

class StopPipelineExecutionInput < Struct.new(
  :pipeline_name,
  :pipeline_execution_id,
  :abandon,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_nameString

The name of the pipeline to stop.



5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-codepipeline/types.rb', line 5536

class StopPipelineExecutionInput < Struct.new(
  :pipeline_name,
  :pipeline_execution_id,
  :abandon,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

Use this option to enter comments, such as the reason the pipeline was stopped.



5536
5537
5538
5539
5540
5541
5542
5543
# File 'lib/aws-sdk-codepipeline/types.rb', line 5536

class StopPipelineExecutionInput < Struct.new(
  :pipeline_name,
  :pipeline_execution_id,
  :abandon,
  :reason)
  SENSITIVE = []
  include Aws::Structure
end