Class: Aws::CodePipeline::Types::RetryStageExecutionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CodePipeline::Types::RetryStageExecutionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-codepipeline/types.rb
Overview
Represents the input of a RetryStageExecution action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#pipeline_execution_id ⇒ String
The ID of the pipeline execution in the failed stage to be retried.
-
#pipeline_name ⇒ String
The name of the pipeline that contains the failed stage.
-
#retry_mode ⇒ String
The scope of the retry attempt.
-
#stage_name ⇒ String
The name of the failed stage to be retried.
Instance Attribute Details
#pipeline_execution_id ⇒ String
The ID of the pipeline execution in the failed stage to be retried. Use the GetPipelineState action to retrieve the current pipelineExecutionId of the failed stage
4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473 class RetryStageExecutionInput < Struct.new( :pipeline_name, :stage_name, :pipeline_execution_id, :retry_mode) SENSITIVE = [] include Aws::Structure end |
#pipeline_name ⇒ String
The name of the pipeline that contains the failed stage.
4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473 class RetryStageExecutionInput < Struct.new( :pipeline_name, :stage_name, :pipeline_execution_id, :retry_mode) SENSITIVE = [] include Aws::Structure end |
#retry_mode ⇒ String
The scope of the retry attempt.
4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473 class RetryStageExecutionInput < Struct.new( :pipeline_name, :stage_name, :pipeline_execution_id, :retry_mode) SENSITIVE = [] include Aws::Structure end |
#stage_name ⇒ String
The name of the failed stage to be retried.
4473 4474 4475 4476 4477 4478 4479 4480 |
# File 'lib/aws-sdk-codepipeline/types.rb', line 4473 class RetryStageExecutionInput < Struct.new( :pipeline_name, :stage_name, :pipeline_execution_id, :retry_mode) SENSITIVE = [] include Aws::Structure end |